@@ -451,7 +451,7 @@ setMethod("initialize", "Stock", function(.Object, file = NA) {
       .Object@Prob_staying <- as.numeric(dat[match("Prob_staying", dname), 1:2])
       .Object@L50 <- as.numeric(dat[match("L50", dname), 1:2])
       .Object@L50_95 <- as.numeric(dat[match("L50_95", dname), 1:2])
-      .Object@FecB <- as.numeric(dat[match("FecB", dname), 1:2])
+      #.Object@FecB <- as.numeric(dat[match("FecB", dname), 1:2])
       .Object@Source <- dat[match("Source", dname), 1]
     } else {
       message("File doesn't exist")
@@ -990,7 +990,7 @@ setMethod("initialize", "OM", function(.Object, Stock=NULL, Fleet=DLMtool::Gener
   if(length(.Object@Mexp) < 2) .Object@Mexp <- c(0,0)
   if(length(.Object@LenCV) < 2) .Object@LenCV <- c(0.08,0.15)
   if(length(.Object@CurrentYr)==0).Object@CurrentYr=.Object@nyears
-  if(length(.Object@FecB) < 2) .Object@FecB <- c(3,3)
+  # if(length(.Object@FecB) < 2) .Object@FecB <- c(3,3)
   
   if(all(is.na(.Object@Mexp))) .Object@Mexp <- c(0,0)
   if(all(is.na(.Object@LenCV))) .Object@LenCV <- c(0.08,0.15)
